@@ -17,6 +17,8 @@
 #' summed for a same concentration
 #' @param log.scale if \code{TRUE}, displays \eqn{x}-axis in log-scale
 #' @param addlegend if \code{TRUE}, adds a default legend to the plot
+#' @param remove.someLabels if \code{TRUE}, removes 3/4 of X-axis labels in
+#' \code{'ggplot'} style to avoid the label overlap
 #' @param \dots Further arguments to be passed to generic methods.
 #' @note When \code{style = "ggplot"}, the function calls package
 #' \code{\link[ggplot2]{ggplot2}} and returns an object of class \code{ggplot}.
@@ -42,16 +44,14 @@
 #' # (5) Plot the reproduction data for a fixed concentration and target.time
 #' plot(cadmium1, target.time = 21, concentration = 0.86)
 #'
-#'
-#' @export
-#'
 #' @import ggplot2
 #' @import grDevices
 #' @importFrom graphics plot axis legend lines par points polygon
 #' segments title
 #' @importFrom methods is
 #' @importFrom stats aggregate
-#'
+#' 
+#' @export
 plot.reproData <- function(x,
                            xlab,
                            ylab = "Cumulated Number of offspring",
@@ -61,25 +61,28 @@ plot.reproData <- function(x,
                            style = "generic",
                            pool.replicate = FALSE,
                            log.scale = FALSE,
-                           addlegend = FALSE, ...) {
+                           addlegend = FALSE,
+                           remove.someLabels = FALSE, ...) {
   if(! is(x, "reproData"))
     stop("plot.reproData: object of class reproData expected")
-  
+
   if (pool.replicate) {
     # agregate by sum of replicate
-    x <- cbind(aggregate(Nreprocumul ~ time + conc, x, sum),
+    x <- cbind(aggregate(cbind(Nreprocumul, Nsurv, Ninit) ~ time + conc, x, sum),
                replicate = 1)
   }
-  
+
   if (is.null(target.time) && is.null(concentration)) {
-    reproDataPlotFull(x, xlab, ylab, style, addlegend)
+    reproDataPlotFull(x, xlab, ylab, style, remove.someLabels)
   }
   else if (! is.null(target.time) && is.null(concentration)) {
     reproDataPlotTargetTime(x, xlab, ylab, main, target.time,
-                            style, log.scale, addlegend)
+                            style, log.scale, addlegend,
+                            remove.someLabels)
   }
   else if (is.null(target.time) && ! is.null(concentration)) {
-    reproDataPlotFixedConc(x, xlab, ylab, main, concentration, style, addlegend)
+    reproDataPlotFixedConc(x, xlab, ylab, main, concentration, style, addlegend,
+                           remove.someLabels)
   }
   else {
     reproDataPlotReplicates(x, xlab, ylab, target.time, concentration,
@@ -90,8 +93,9 @@ plot.reproData <- function(x,
 
 
 reproDataPlotFull <- function(data, xlab, ylab, style = "generic",
-                              addlegend = TRUE) {
-  dataPlotFull(data, xlab, ylab, "Nreprocumul", style, addlegend)
+                              remove.someLabels) {
+  dataPlotFull(data, xlab, ylab, "Nreprocumul", style,
+               remove.someLabels)
 }
 
 
@@ -104,7 +108,8 @@ reproDataPlotTargetTime <- function(x,
                                     target.time,
                                     style,
                                     log.scale,
-                                    addlegend) {
+                                    addlegend,
+                                    remove.someLabels) {
 
   if (missing(xlab)) xlab <-"Concentration"
 
@@ -121,13 +126,13 @@ reproDataPlotTargetTime <- function(x,
   sel <- if(log.scale) xf$conc > 0 else TRUE
   x <- xf[sel, ]
   transf_data_conc <- optLogTransform(log.scale, x$conc)
-  
+
   # Concentration values used for display in linear scale
   display.conc <- (function() {
     x <- optLogTransform(log.scale, x$conc)
     if(log.scale) exp(x) else x
   })()
-  
+
   # Define visual parameters
   mortality <- c(0, 1) # code 0/1 mortality
   nomortality <- match(x$Nsurv == x$Ninit, c(TRUE, FALSE))
@@ -183,15 +188,27 @@ reproDataPlotTargetTime <- function(x,
     gp <- ggplot(df, aes(transf_data_conc, Nreprocumul,
                          fill = Mortality)) +
       geom_point(size = 3, pch = 21) +
-      scale_fill_manual(values = c("black", "white")) +
+      scale_fill_manual(values = if (
+        length(levels(df$Mortality)) == 1 && levels(df$Mortality) == "Yes") {
+        "white"
+        } else if (length(levels(df$Mortality)) == 1 &&
+                   levels(df$Mortality) == "No") {
+          "black"
+        } else {
+          c("black", "white")
+        }) +
       labs(x = xlab, y = ylab) +
       ggtitle(main) +
       theme_minimal() +
       scale_colour_hue(legend.title, breaks = c("No","Yes"),
                        labels = c(legend.name.no, legend.name.yes)) +
       scale_x_continuous(breaks = df$transf_data_conc,
-                         labels = df$display.conc)
-    
+                         labels = if (remove.someLabels) {
+                           exclude_labels(df$display.conc)
+                         } else {
+                           df$display.conc
+                         })
+
     if (addlegend) {
       return(gp)
     } else {
@@ -207,9 +224,10 @@ reproDataPlotFixedConc <- function(x,
                                    main,
                                    concentration,
                                    style = "generic",
-                                   addlegend = FALSE) {
+                                   addlegend = FALSE,
+                                   remove.someLabels = FALSE) {
   dataPlotFixedConc(x, xlab, ylab, main, "Nreprocumul",
-                    concentration, style, addlegend)
+                    concentration, style, addlegend, remove.someLabels)
 }
 
 reproDataPlotReplicates <- function(x,
